#line 1 "eval-coin.cpp"
/**************************************************************************\
 * Copyright (c) Kongsberg Oil & Gas Technologies AS
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * 
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * 
 * Neither the name of the copyright holder nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
\**************************************************************************/

/* Run 'flex eval-coin.l' to generate the compilable source files */

#include <cmath>
#include <cfloat>
#include "soscxml/eval-coin.h"
#ifndef SCXML_COIN_OP_ADD
#include "soscxml/eval-coin-tab.hpp"
#else
#endif // !SCXML_COIN_OP_ADD

#line 44 "eval-coin.cpp"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer scxml_coin__create_buffer
#define yy_delete_buffer scxml_coin__delete_buffer
#define yy_flex_debug scxml_coin__flex_debug
#define yy_init_buffer scxml_coin__init_buffer
#define yy_flush_buffer scxml_coin__flush_buffer
#define yy_load_buffer_state scxml_coin__load_buffer_state
#define yy_switch_to_buffer scxml_coin__switch_to_buffer
#define yyin scxml_coin_in
#define yyleng scxml_coin_leng
#define yylex scxml_coin_lex
#define yylineno scxml_coin_lineno
#define yyout scxml_coin_out
#define yyrestart scxml_coin_restart
#define yytext scxml_coin_text
#define yywrap scxml_coin_wrap
#define yyalloc scxml_coin_alloc
#define yyrealloc scxml_coin_realloc
#define yyfree scxml_coin_free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 3
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

    #define yy_create_buffer scxml_coin__create_buffer

    #define yy_delete_buffer scxml_coin__delete_buffer

    #define yy_scan_buffer scxml_coin__scan_buffer

    #define yy_scan_string scxml_coin__scan_string

    #define yy_scan_bytes scxml_coin__scan_bytes

    #define yy_init_buffer scxml_coin__init_buffer

    #define yy_flush_buffer scxml_coin__flush_buffer

    #define yy_load_buffer_state scxml_coin__load_buffer_state

    #define yy_switch_to_buffer scxml_coin__switch_to_buffer

    #define yypush_buffer_state scxml_coin_push_buffer_state

    #define yypop_buffer_state scxml_coin_pop_buffer_state

    #define yyensure_buffer_stack scxml_coin_ensure_buffer_stack

    #define yylex scxml_coin_lex

    #define yyrestart scxml_coin_restart

    #define yylex_init scxml_coin_lex_init

    #define yylex_init_extra scxml_coin_lex_init_extra

    #define yylex_destroy scxml_coin_lex_destroy

    #define yyget_debug scxml_coin_get_debug

    #define yyset_debug scxml_coin_set_debug

    #define yyget_extra scxml_coin_get_extra

    #define yyset_extra scxml_coin_set_extra

    #define yyget_in scxml_coin_get_in

    #define yyset_in scxml_coin_set_in

    #define yyget_out scxml_coin_get_out

    #define yyset_out scxml_coin_set_out

    #define yyget_leng scxml_coin_get_leng

    #define yyget_text scxml_coin_get_text

    #define yyget_lineno scxml_coin_get_lineno

    #define yyset_lineno scxml_coin_set_lineno

    #define yywrap scxml_coin_wrap

    #define yyalloc scxml_coin_alloc

    #define yyrealloc scxml_coin_realloc

    #define yyfree scxml_coin_free

    #define yytext scxml_coin_text

    #define yyleng scxml_coin_leng

    #define yyin scxml_coin_in

    #define yyout scxml_coin_out

    #define yy_flex_debug scxml_coin__flex_debug

    #define yylineno scxml_coin_lineno

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE scxml_coin_restart(scxml_coin_in  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int scxml_coin_leng;

extern FILE *scxml_coin_in, *scxml_coin_out;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up scxml_coin_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up scxml_coin_text again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via scxml_coin_restart()), so that the user can continue scanning by
	 * just pointing scxml_coin_in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when scxml_coin_text is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int scxml_coin_leng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow scxml_coin_wrap()'s to do buffer switches
 * instead of setting up a fresh scxml_coin_in.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void scxml_coin_restart ( FILE *input_file  );
void scxml_coin__switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE scxml_coin__create_buffer ( FILE *file, int size  );
void scxml_coin__delete_buffer ( YY_BUFFER_STATE b  );
void scxml_coin__flush_buffer ( YY_BUFFER_STATE b  );
void scxml_coin_push_buffer_state ( YY_BUFFER_STATE new_buffer  );
void scxml_coin_pop_buffer_state ( void );

static void scxml_coin_ensure_buffer_stack ( void );
static void scxml_coin__load_buffer_state ( void );
static void scxml_coin__init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER scxml_coin__flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE scxml_coin__scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE scxml_coin__scan_string ( const char *yy_str  );
YY_BUFFER_STATE scxml_coin__scan_bytes ( const char *bytes, int len  );

void *scxml_coin_alloc ( yy_size_t  );
void *scxml_coin_realloc ( void *, yy_size_t  );
void scxml_coin_free ( void *  );

#define yy_new_buffer scxml_coin__create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        scxml_coin_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            scxml_coin__create_buffer(scxml_coin_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        scxml_coin_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            scxml_coin__create_buffer(scxml_coin_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define scxml_coin_wrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

FILE *scxml_coin_in = NULL, *scxml_coin_out = NULL;

typedef int yy_state_type;

extern int scxml_coin_lineno;
int scxml_coin_lineno = 1;

extern char *scxml_coin_text;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr scxml_coin_text

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up scxml_coin_text.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	scxml_coin_leng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 35
#define YY_END_OF_BUFFER 36
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[162] =
    {   0,
        0,    0,   36,   35,    1,   34,   35,   35,   17,   18,
       32,   30,   31,   33,    4,   35,   25,   25,   25,   25,
       25,   25,   25,   35,   25,   25,   25,   35,    1,   27,
       29,    0,   16,    4,    0,    0,   26,    0,   25,   25,
       25,   25,   19,   25,   25,   25,   25,   25,    0,    0,
       25,   25,   25,   28,    4,    0,    4,   25,   25,   25,
       25,   25,    9,   25,   25,   25,    0,    0,   25,   25,
       25,    0,    0,   25,   25,   25,   25,   25,   25,   25,
       25,   25,    5,   25,    0,    0,   15,    2,    0,    0,
       25,   25,    3,   25,   25,   12,   25,   25,   25,   15,

        0,    0,    0,   25,   25,   20,   25,   25,    6,   25,
        0,    0,    0,    0,    7,    8,   25,   10,   25,   13,
       22,    0,    0,    0,   11,   25,    0,   22,   21,    0,
        0,   14,   22,    0,    0,   21,    0,    0,   21,   21,
        0,    0,    0,   21,    0,   24,   21,    0,    0,   24,
       23,   24,    0,    0,   23,   23,   23,    0,   23,   23,
        0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    3,    1,    1,    1,    1,    4,    5,    6,
        7,    8,    9,    1,   10,   11,   12,   13,   14,   15,
       16,   16,   16,   16,   16,   16,   16,   17,    1,    1,
       18,    1,    1,    1,   19,   20,   20,   20,   21,   22,
       23,   20,   24,   20,   20,   25,   26,   27,   28,   29,
       30,   31,   32,   33,   34,   20,   20,   35,   20,   20,
        1,    1,    1,    1,   36,    1,   37,   38,   39,   40,

       41,   42,   43,   44,   45,   20,   20,   46,   47,   48,
       49,   50,   20,   51,   52,   53,   54,   55,   20,   20,
       20,   20,    1,   56,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[57] =
    {   0,
        1,    1,    1,    1,    1,    2,    1,    1,    1,    1,
        3,    1,    2,    2,    2,    2,    1,    1,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    2,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    1
    } ;

static const flex_int16_t yy_base[179] =
    {   0,
        0,    0,  372,  373,  369,  352,  365,  363,  373,  373,
      373,   44,   48,  373,   54,  349,  360,   60,   65,   66,
       67,   68,   70,   37,   74,   75,   76,  309,  362,  373,
      373,  358,  373,   73,   77,   95,  373,  355,  355,   77,
       92,   90,  354,   93,  110,  142,   94,  109,  322,  303,
      111,  112,  113,  373,  155,  159,  164,  373,  123,  126,
      114,  118,  351,  158,  116,  127,  350,  348,  198,  176,
      124,  301,  312,  175,  131,  178,  205,  186,  181,  182,
      212,  207,  184,  183,  345,  344,  373,  344,  312,  300,
      211,  188,  341,  215,  187,  340,  218,  230,  219,  373,

      334,  291,  198,  232,  234,  337,  235,  236,  336,  241,
        0,  330,  303,  298,  332,  331,  237,  330,  238,  329,
      328,    0,  286,  285,  325,  244,  323,  323,  254,  287,
      277,  320,  373,  318,    0,  257,  273,  312,  311,  258,
      284,    0,  313,  260,  308,  305,  291,    0,  280,  274,
      264,  373,  272,    0,  266,  251,  267,  246,  270,  238,
      373,  281,  284,  288,  292,  296,  242,  299,  191,  302,
      187,  305,  134,  308,  130,  311,  122,  314
    } ;

static const flex_int16_t yy_def[179] =
    {   0,
      161,    1,  161,  161,  161,  161,  161,  162,  161,  161,
      161,  161,  161,  161,  161,  161,  163,  163,  163,  163,
      163,  163,  163,  161,  163,  163,  163,  161,  161,  161,
      161,  162,  161,  161,  161,  161,  161,  161,  163,  163,
      163,  163,  163,  163,  163,  164,  163,  163,  161,  161,
      163,  163,  163,  161,  161,  161,  161,  161,  163,  163,
      163,  163,  163,  163,  163,  163,  165,  166,  164,  163,
      163,  161,  161,  163,  163,  163,  163,  163,  163,  163,
      163,  163,  163,  163,  166,  166,  161,  163,  161,  161,
      163,  163,  163,  163,  163,  163,  163,  163,  163,  161,

      161,  161,  161,  163,  163,  163,  163,  163,  163,  163,
      167,  161,  161,  161,  163,  163,  163,  163,  163,  163,
      168,  169,  161,  161,  163,  163,  161,  168,  170,  161,
      161,  163,  161,  161,  171,  170,  161,  161,  161,  172,
      161,  173,  161,  172,  161,  174,  161,  175,  161,  174,
      176,  161,  161,  177,  176,  161,  178,  161,  178,  161,
        0,  161,  161,  161,  161,  161,  161,  161,  161,  161,
      161,  161,  161,  161,  161,  161,  161,  161
    } ;

static const flex_int16_t yy_nxt[430] =
    {   0,
        4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
        4,   14,   15,   15,   15,   15,    4,   16,   17,   17,
       17,   18,   17,   19,   20,   21,   17,   17,   17,   17,
       17,   22,   23,   17,   17,   24,   17,   17,   25,   17,
       17,   26,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   27,   17,   17,   28,   34,   34,   34,   34,
       34,   34,   34,   34,   35,   38,   34,   34,   34,   34,
       38,   38,   38,   38,   36,   38,   49,   50,   40,   38,
       38,   38,   38,   35,   41,   34,   34,   34,   34,   55,
       55,   55,   55,   36,   36,   38,   42,   38,   38,   38,

       47,   59,   45,   56,   56,   46,   44,   57,   57,   57,
       57,   52,   43,   36,   38,   38,   38,   38,   38,   38,
       48,   38,   51,   38,   60,  157,   53,   70,   38,   38,
       63,   38,   38,  151,   64,   61,   38,  146,   65,   83,
       62,   66,   67,   67,   67,   67,   67,   68,   67,   67,
       67,   67,   67,   67,   77,   74,   84,   75,   67,   67,
       80,   78,   71,   38,   88,   79,   76,   55,   55,   55,
       55,   57,   57,   57,   57,   36,   57,   57,   57,   57,
       38,   38,   92,   38,   81,   82,   38,   38,   38,   38,
      140,   38,   38,   38,  129,   36,   88,   67,   67,   67,

       67,   67,   67,   68,   67,   67,   67,   67,   67,   67,
       38,   94,   38,   99,   67,   67,   38,   38,   88,   98,
       38,   93,   91,   38,   38,   93,   96,  103,   93,   97,
      106,  107,  108,  104,   95,   38,  113,   38,  105,   38,
       38,   38,   38,   38,  109,  121,   38,  117,  154,   38,
      114,  110,  160,   67,  119,  120,  118,  125,  132,  134,
      116,  154,  134,  143,  135,  143,  115,  135,  135,  153,
      135,  153,  158,  126,  154,  158,  154,  154,  156,  149,
      154,   32,   32,   32,   32,   39,  152,   39,   69,   69,
       69,   69,   67,   67,   67,   67,   86,   86,   86,   86,

      128,  135,  128,  136,  136,  136,  144,  144,  144,  150,
      149,  150,  155,  155,  155,  159,  159,  159,  148,  147,
      145,  135,  142,  141,  139,   38,  138,  137,  127,  133,
       38,  131,  130,  127,   38,   38,   38,   38,  124,  123,
      122,   38,   38,  112,  111,   38,   38,  102,  101,   38,
      100,  100,   90,   89,   87,   85,   38,   73,   72,   38,
       38,   58,   33,   29,   54,   38,   37,   33,   31,   30,
       29,  161,    3,  161,  161,  161,  161,  161,  161,  161,
      161,  161,  161,  161,  161,  161,  161,  161,  161,  161,
      161,  161,  161,  161,  161,  161,  161,  161,  161,  161,

      161,  161,  161,  161,  161,  161,  161,  161,  161,  161,
      161,  161,  161,  161,  161,  161,  161,  161,  161,  161,
      161,  161,  161,  161,  161,  161,  161,  161,  161
    } ;

static const flex_int16_t yy_chk[430] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,   12,   12,   12,   12,
       13,   13,   13,   13,   15,   18,   15,   15,   15,   15,
       19,   20,   21,   22,   15,   23,   24,   24,   18,   25,
       26,   27,   40,   34,   18,   34,   34,   34,   34,   35,
       35,   35,   35,   34,   15,   42,   18,   41,   44,   47,

       23,   40,   21,   36,   36,   22,   20,   36,   36,   36,
       36,   26,   19,   34,   48,   45,   51,   52,   53,   61,
       23,   65,   25,   62,   41,  177,   27,   47,   59,   71,
       45,   60,   66,  175,   45,   42,   75,  173,   45,   65,
       44,   45,   46,   46,   46,   46,   46,   46,   46,   46,
       46,   46,   46,   46,   59,   51,   66,   52,   46,   46,
       62,   60,   48,   64,   71,   61,   53,   55,   55,   55,
       55,   56,   56,   56,   56,   55,   57,   57,   57,   57,
       74,   70,   75,   76,   64,   64,   79,   80,   84,   83,
      171,   78,   95,   92,  169,   55,   70,   46,   69,   69,

       69,   69,   69,   69,   69,   69,   69,   69,   69,   69,
       77,   78,   82,   84,   69,   69,   91,   81,   76,   83,
       94,   79,   74,   97,   99,   77,   81,   91,   92,   82,
       95,   97,   97,   94,   80,   98,  103,  104,   94,  105,
      107,  108,  117,  119,   98,  167,  110,  107,  160,  126,
      103,   99,  158,   69,  110,  110,  108,  117,  126,  129,
      105,  156,  136,  140,  129,  144,  104,  136,  140,  151,
      144,  155,  157,  119,  151,  159,  155,  157,  153,  150,
      159,  162,  162,  162,  162,  163,  149,  163,  164,  164,
      164,  164,  165,  165,  165,  165,  166,  166,  166,  166,

      168,  147,  168,  170,  170,  170,  172,  172,  172,  174,
      146,  174,  176,  176,  176,  178,  178,  178,  145,  143,
      141,  139,  138,  137,  134,  132,  131,  130,  128,  127,
      125,  124,  123,  121,  120,  118,  116,  115,  114,  113,
      112,  109,  106,  102,  101,   96,   93,   90,   89,   88,
       86,   85,   73,   72,   68,   67,   63,   50,   49,   43,
       39,   38,   32,   29,   28,   17,   16,    8,    7,    6,
        5,    3,  161,  161,  161,  161,  161,  161,  161,  161,
      161,  161,  161,  161,  161,  161,  161,  161,  161,  161,
      161,  161,  161,  161,  161,  161,  161,  161,  161,  161,

      161,  161,  161,  161,  161,  161,  161,  161,  161,  161,
      161,  161,  161,  161,  161,  161,  161,  161,  161,  161,
      161,  161,  161,  161,  161,  161,  161,  161,  161
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int scxml_coin__flex_debug;
int scxml_coin__flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *scxml_coin_text;
#line 1 "eval-coin.l"

#define YY_NO_INPUT 1
#line 728 "eval-coin.cpp"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif
    
#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int scxml_coin_lex_destroy ( void );

int scxml_coin_get_debug ( void );

void scxml_coin_set_debug ( int debug_flag  );

YY_EXTRA_TYPE scxml_coin_get_extra ( void );

void scxml_coin_set_extra ( YY_EXTRA_TYPE user_defined  );

FILE *scxml_coin_get_in ( void );

void scxml_coin_set_in  ( FILE * _in_str  );

FILE *scxml_coin_get_out ( void );

void scxml_coin_set_out  ( FILE * _out_str  );

			int scxml_coin_get_leng ( void );

char *scxml_coin_get_text ( void );

int scxml_coin_get_lineno ( void );

void scxml_coin_set_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int scxml_coin_wrap ( void );
#else
extern int scxml_coin_wrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( scxml_coin_text, (size_t) scxml_coin_leng, 1, scxml_coin_out )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( scxml_coin_in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( scxml_coin_in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, scxml_coin_in)) == 0 && ferror(scxml_coin_in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(scxml_coin_in); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int scxml_coin_lex (void);

#define YY_DECL int scxml_coin_lex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after scxml_coin_text and scxml_coin_leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! scxml_coin_in )
			scxml_coin_in = stdin;

		if ( ! scxml_coin_out )
			scxml_coin_out = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			scxml_coin_ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				scxml_coin__create_buffer(scxml_coin_in,YY_BUF_SIZE );
		}

		scxml_coin__load_buffer_state( );
		}

	{
#line 74 "eval-coin.l"


#line 946 "eval-coin.cpp"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of scxml_coin_text. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 162 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 161 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 76 "eval-coin.l"
{ }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 77 "eval-coin.l"
{ return SCXML_COIN_BOOL_TRUE; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 78 "eval-coin.l"
{ return SCXML_COIN_BOOL_FALSE; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 79 "eval-coin.l"
{ scxml_coin_lval.real = atof(yytext); return SCXML_COIN_REAL; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 80 "eval-coin.l"
{ scxml_coin_lval.real = M_PI; return SCXML_COIN_REAL; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 81 "eval-coin.l"
{ scxml_coin_lval.real = M_PI_2; return SCXML_COIN_REAL; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 82 "eval-coin.l"
{ scxml_coin_lval.real = FLT_MAX; return SCXML_COIN_REAL; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 83 "eval-coin.l"
{ scxml_coin_lval.real = FLT_MIN; return SCXML_COIN_REAL; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 84 "eval-coin.l"
{ scxml_coin_lval.real = M_E; return SCXML_COIN_REAL; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 85 "eval-coin.l"
{ scxml_coin_lval.real = M_LOG2E; return SCXML_COIN_REAL; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 86 "eval-coin.l"
{ scxml_coin_lval.real = M_LOG10E; return SCXML_COIN_REAL; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 87 "eval-coin.l"
{ scxml_coin_lval.real = M_LN2; return SCXML_COIN_REAL; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 88 "eval-coin.l"
{ scxml_coin_lval.real = M_SQRT2; return SCXML_COIN_REAL; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 89 "eval-coin.l"
{ scxml_coin_lval.real = M_SQRT1_2; return SCXML_COIN_REAL; }
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 90 "eval-coin.l"
{ scxml_coin_lval.stringptr = yytext; return SCXML_COIN_SBVALUE; }
	YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 91 "eval-coin.l"
{ scxml_coin_lval.stringptr = yytext; return SCXML_COIN_STRING; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 92 "eval-coin.l"
{ return SCXML_COIN_PAREN_OPEN; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 93 "eval-coin.l"
{ return SCXML_COIN_PAREN_CLOSE; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 95 "eval-coin.l"
{ return SCXML_COIN_IN_FUNC; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 96 "eval-coin.l"
{ return SCXML_COIN_LENGTH_FUNC; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 97 "eval-coin.l"
{ scxml_coin_lval.stringptr = yytext;
                      return SCXML_COIN_IDENTIFIER; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 99 "eval-coin.l"
{ scxml_coin_lval.stringptr = yytext;
                      return SCXML_COIN_IDENTIFIER; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 101 "eval-coin.l"
{ scxml_coin_lval.stringptr = yytext;
                      return SCXML_COIN_IDENTIFIER; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 103 "eval-coin.l"
{ scxml_coin_lval.stringptr = yytext;
                      return SCXML_COIN_IDENTIFIER; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 105 "eval-coin.l"
{ scxml_coin_lval.stringptr = yytext;
                      return SCXML_COIN_IDENTIFIER; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 108 "eval-coin.l"
{ return SCXML_COIN_OP_EQUALS; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 109 "eval-coin.l"
{ return SCXML_COIN_OP_NOT_EQUALS; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 110 "eval-coin.l"
{ return SCXML_COIN_OP_OR; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 111 "eval-coin.l"
{ return SCXML_COIN_OP_AND; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 112 "eval-coin.l"
{ return SCXML_COIN_OP_ADD; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 113 "eval-coin.l"
{ return SCXML_COIN_OP_SUBTRACT; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 114 "eval-coin.l"
{ return SCXML_COIN_OP_MULTIPLY; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 115 "eval-coin.l"
{ return SCXML_COIN_OP_DIVIDE; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 116 "eval-coin.l"
{ return SCXML_COIN_OP_NOT; }
	YY_BREAK
/* <<EOF>>             { return SCXML_COIN_END; } */
case 35:
YY_RULE_SETUP
#line 120 "eval-coin.l"
ECHO;
	YY_BREAK
#line 1182 "eval-coin.cpp"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed scxml_coin_in at a new source and called
			 * scxml_coin_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = scxml_coin_in;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( scxml_coin_wrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * scxml_coin_text, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of scxml_coin_lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					scxml_coin_realloc((void *) b->yy_ch_buf,(yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			scxml_coin_restart(scxml_coin_in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) scxml_coin_realloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,(yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 162 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 162 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 161);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					scxml_coin_restart(scxml_coin_in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( scxml_coin_wrap( ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve scxml_coin_text */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void scxml_coin_restart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        scxml_coin_ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            scxml_coin__create_buffer(scxml_coin_in,YY_BUF_SIZE );
	}

	scxml_coin__init_buffer(YY_CURRENT_BUFFER,input_file );
	scxml_coin__load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void scxml_coin__switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		scxml_coin_pop_buffer_state();
	 *		scxml_coin_push_buffer_state(new_buffer);
     */
	scxml_coin_ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	scxml_coin__load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (scxml_coin_wrap()) processing, but the only time this flag
	 * is looked at is after scxml_coin_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void scxml_coin__load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	scxml_coin_in = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE scxml_coin__create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) scxml_coin_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in scxml_coin__create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) scxml_coin_alloc((yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in scxml_coin__create_buffer()" );

	b->yy_is_our_buffer = 1;

	scxml_coin__init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with scxml_coin__create_buffer()
 * 
 */
    void scxml_coin__delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		scxml_coin_free((void *) b->yy_ch_buf  );

	scxml_coin_free((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a scxml_coin_restart() or at EOF.
 */
    static void scxml_coin__init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	scxml_coin__flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then scxml_coin__init_buffer was _probably_
     * called from scxml_coin_restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void scxml_coin__flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		scxml_coin__load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void scxml_coin_push_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	scxml_coin_ensure_buffer_stack();

	/* This block is copied from scxml_coin__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from scxml_coin__switch_to_buffer. */
	scxml_coin__load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void scxml_coin_pop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	scxml_coin__delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		scxml_coin__load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void scxml_coin_ensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)scxml_coin_alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in scxml_coin_ensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)scxml_coin_realloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in scxml_coin_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE scxml_coin__scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) scxml_coin_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in scxml_coin__scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	scxml_coin__switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to scxml_coin_lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       scxml_coin__scan_bytes() instead.
 */
YY_BUFFER_STATE scxml_coin__scan_string (const char * yystr )
{
    
	return scxml_coin__scan_bytes(yystr,(int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to scxml_coin_lex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE scxml_coin__scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) scxml_coin_alloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in scxml_coin__scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = scxml_coin__scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in scxml_coin__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up scxml_coin_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		scxml_coin_text[scxml_coin_leng] = (yy_hold_char); \
		(yy_c_buf_p) = scxml_coin_text + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		scxml_coin_leng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int scxml_coin_get_lineno  (void)
{
    
    return scxml_coin_lineno;
}

/** Get the input stream.
 * 
 */
FILE *scxml_coin_get_in  (void)
{
        return scxml_coin_in;
}

/** Get the output stream.
 * 
 */
FILE *scxml_coin_get_out  (void)
{
        return scxml_coin_out;
}

/** Get the length of the current token.
 * 
 */
int scxml_coin_get_leng  (void)
{
        return scxml_coin_leng;
}

/** Get the current token.
 * 
 */

char *scxml_coin_get_text  (void)
{
        return scxml_coin_text;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void scxml_coin_set_lineno (int  _line_number )
{
    
    scxml_coin_lineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see scxml_coin__switch_to_buffer
 */
void scxml_coin_set_in (FILE *  _in_str )
{
        scxml_coin_in = _in_str ;
}

void scxml_coin_set_out (FILE *  _out_str )
{
        scxml_coin_out = _out_str ;
}

int scxml_coin_get_debug  (void)
{
        return scxml_coin__flex_debug;
}

void scxml_coin_set_debug (int  _bdebug )
{
        scxml_coin__flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from scxml_coin_lex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    scxml_coin_in = stdin;
    scxml_coin_out = stdout;
#else
    scxml_coin_in = NULL;
    scxml_coin_out = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * scxml_coin_lex_init()
     */
    return 0;
}

/* scxml_coin_lex_destroy is for both reentrant and non-reentrant scanners. */
int scxml_coin_lex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		scxml_coin__delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		scxml_coin_pop_buffer_state();
	}

	/* Destroy the stack itself. */
	scxml_coin_free((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * scxml_coin_lex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *scxml_coin_alloc (yy_size_t  size )
{
			return malloc(size);
}

void *scxml_coin_realloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void scxml_coin_free (void * ptr )
{
			free( (char *) ptr );	/* see scxml_coin_realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 120 "eval-coin.l"



int
scxml_coin_error(const char * error)
{
  printf("\nscxml_coin error: %s\n", error);
  return 0;
}

ScXMLDataObj *
scxml_coin_parse(const char * buffer)
{
  YY_BUFFER_STATE yybuf = scxml_coin__scan_string(buffer);
  scxml_coin__switch_to_buffer(yybuf);
  scxml_coin_parse(); // the bison function
  scxml_coin__delete_buffer(yybuf);
  ScXMLDataObj * dataobj = scxml_coin_get_root_obj();
  scxml_coin_clear_root_obj();
  return dataobj;
}


